imgbuild

package
v1.1.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 16, 2025 License: Apache-2.0 Imports: 21 Imported by: 0

Documentation

Overview

Copyright Red Hat Inc.

Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.

Index

Constants

const DockerfileTemplate = `` /* 187-byte string literal not displayed */

Variables

This section is empty.

Functions

func BuildTritonSummary added in v1.1.0

func BuildTritonSummary(metadata []CacheMetadata) (*preflightcheck.TritonSummary, error)

BuildTritonSummary deduplicates kernel targets and produces a compact summary for labeling.

Types

type CacheMetadata added in v1.1.0

type CacheMetadata struct {
	Hash       string `json:"hash"`
	Backend    string `json:"backend"`
	Arch       string `json:"arch"`
	WarpSize   int    `json:"warp_size"`
	PTXVersion *int   `json:"ptx_version,omitempty"`
	NumStages  int    `json:"num_stages,omitempty"`
	NumWarps   int    `json:"num_warps,omitempty"`
	Debug      bool   `json:"debug,omitempty"`
	DummyKey   string `json:"dummy_key"`
}

type DockerfileData

type DockerfileData struct {
	ImageTitle  string
	CacheDir    string
	ManifestDir string
}

type ImageBuilder

type ImageBuilder interface {
	CreateImage(imgName string, cacheDir string) error
}

func New

func New() (ImageBuilder, error)

Factory function to create a new ImgBuilder with the specified backend.

Jump to